@@ -1,15 +1,18 @@
 #include "horizontalcall.h"
+#include "appsettingsmanager.h"
 #include "ui_horizontalcall.h"
 
+#include <QtMaemo5>
+#include <QtDBus>
+
 using namespace QtMobility;
 
 horizontalcall::horizontalcall(QWidget *parent) :
-    QMainWindow(parent),
-    ui(new Ui::horizontalcall)
+        QMainWindow(parent),
+        ui(new Ui::horizontalcall)
 {
-    m_Maximized = true;
     m_Landscape = true;
-    m_FetchPending = true;
+    m_FetchPending = false;
     m_DisplayingContact = false;
     createStyle();
     ui->setupUi(this);
@@ -23,93 +26,106 @@ horizontalcall::horizontalcall(QWidget *parent) :
     existingLetterButtons = new QList<QPushButton*>();
     existingLetters = new QList<QString>();
     m_CurrentFilter = QString();
+
     createSharedUI();
-    //createPortraitUI();
+
     getRotationSettings();
-    if (m_Landscape) {
-        qDebug() << "Init : Autorotation is set to Landscape";
-        //setAttribute(Qt::WA_Maemo5PortraitOrientation, false);
-        setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
-    } else {
-        qDebug() << "Init : Autorotation is set to Portrait";
-        //setAttribute(Qt::WA_Maemo5LandscapeOrientation, false);
-        setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
-    }
     if (m_AutorotationEnabled)
     {
-        qDebug() << "Init : Autorotation is set to automatic";
-        setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+        qDebug() << "Main Thread : Init : Autorotation is set to automatic";
+        rotator = new QtMaemo5Rotator(QtMaemo5Rotator::AutomaticBehavior, this);
+    }
+    else
+    {
+        if (m_Landscape) {
+            qDebug() << "Main Thread : I am in landscape mode";
+            rotator = new QtMaemo5Rotator(QtMaemo5Rotator::LandscapeBehavior, this);
+        } else {
+            qDebug() << "Main Thread : I am in portrait mode";
+            rotator = new QtMaemo5Rotator(QtMaemo5Rotator::PortraitBehavior, this);
+        }
     }
 
-    if (m_Landscape)
-        createLandscapeUI();
-    else
-        createPortraitUI();
+    if (m_AutorotationEnabled) {
+        if (width() > height()) {
+            qDebug() << "Main Thread : Creating landscape UI";
+            createLandscapeUI();
+            m_Landscape = true;
+        } else {
+            qDebug() << "Main Thread : Creating portrait UI";
+            createPortraitUI();
+            m_Landscape = false;
+        }
+    } else {
+        if (m_Landscape) {
+            qDebug() << "Main Thread : Going to Create landscape UI";
+            createLandscapeUI();
+        } else {
+            qDebug() << "Main Thread : Going to Create portrait UI";
+            createPortraitUI();
+        }
+    }
 
     m_scrollArea = NULL;
-    QTimer::singleShot(1000, this, SLOT(populateList()));
-    labelSelector->setText("Loading...");
+    m_FetchPending = true;
+}
 
+void horizontalcall::ContactUpdatesDone()
+{
+    qDebug() << "Main Thread : Done updateing contacts.";
+    m_FetchPending = false;
+    lineEditTextChanged(lineEditFilter->text());
 }
 
 void horizontalcall::getRotationSettings()
 {
-    QSettings settings("horizontal-call");
+    QSettings settings;
     m_AutorotationEnabled = settings.value("AutoRotation", true).value<bool>();
-    qDebug() << "AutoRotation : " << m_AutorotationEnabled;
+    qDebug() << "Main Thread : AutoRotation : " << m_AutorotationEnabled;
     m_Landscape = settings.value("ManualRotationLandscape", true).value<bool>();
-    qDebug() << "ManualRotation : " << m_Landscape;
+    qDebug() << "Main Thread : ManualRotation : " << m_Landscape;
 }
 
 void horizontalcall::doAction1()
 {
+    QSettings settings;
     //Autorotation
     if (m_AutorotationEnabled) {
         QMaemo5InformationBox::information(this, "AutoRotation is now <b>Disabled</b>", QMaemo5InformationBox::DefaultTimeout);
         m_AutorotationEnabled = false;
-        QSettings settings("horizontal-call");
         settings.setValue("AutoRotation", false);
-        setAttribute(Qt::WA_Maemo5AutoOrientation, false);
         if (m_Landscape) {
-            //setAttribute(Qt::WA_Maemo5PortraitOrientation, false);
-            setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
+            rotator->setCurrentBehavior(QtMaemo5Rotator::LandscapeBehavior);
         } else {
-            //setAttribute(Qt::WA_Maemo5LandscapeOrientation, false);
-            setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+            rotator->setCurrentBehavior(QtMaemo5Rotator::PortraitBehavior);
         }
     } else {
         QMaemo5InformationBox::information(this, "AutoRotation is now <b>Enabled</b>", QMaemo5InformationBox::DefaultTimeout);
         m_AutorotationEnabled = true;
-        QSettings settings("horizontal-call");
         settings.setValue("AutoRotation", true);
-        setAttribute(Qt::WA_Maemo5AutoOrientation, true);
+        rotator->setCurrentBehavior(QtMaemo5Rotator::AutomaticBehavior);
     }
 }
 
 void horizontalcall::doAction2()
 {
+    QSettings settings;
     //Manualrotation
     if (m_AutorotationEnabled) {
         m_AutorotationEnabled = false;
-        QSettings settings("horizontal-call");
         settings.setValue("AutoRotation", false);
+        rotator->setCurrentBehavior(QtMaemo5Rotator::AutomaticBehavior);
     }
     if (m_Landscape) {
-        qDebug() << "Switching from landscape to portrait, manual.";
-        QSettings settings("horizontal-call");
+        qDebug() << "Main Thread : Switching from landscape to portrait, manual.";
         settings.setValue("ManualRotationLandscape", false);
         QMaemo5InformationBox::information(this, "Perspective is now : <b>Portrait</b>", QMaemo5InformationBox::DefaultTimeout);
-        //rotator->setCurrentBehavior(QMaemo5Rotator::PortraitBehavior);
-        //setAttribute(Qt::WA_Maemo5LandscapeOrientation, false);
-        setAttribute(Qt::WA_Maemo5PortraitOrientation, true);
+        rotator->setCurrentBehavior(QtMaemo5Rotator::PortraitBehavior);
     } else {
-        qDebug() << "Switching from portrait to landscape, manual.";
-        QSettings settings("horizontal-call");
+        qDebug() << "Main Thread : Switching from portrait to landscape, manual.";
         settings.setValue("ManualRotationLandscape", true);
         QMaemo5InformationBox::information(this, "Perspective is now : <b>Landscape</b>", QMaemo5InformationBox::DefaultTimeout);
-        //rotator->setCurrentBehavior(QMaemo5Rotator::LandscapeBehavior);
-        //setAttribute(Qt::WA_Maemo5PortraitOrientation, false);
-        setAttribute(Qt::WA_Maemo5LandscapeOrientation, true);
+        rotator->setCurrentBehavior(QtMaemo5Rotator::LandscapeBehavior);
     }
 }
 
@@ -128,11 +144,52 @@ void horizontalcall::createSharedUI()
 
     connect(action1, SIGNAL(triggered()), this , SLOT(doAction1()));
     connect(action2, SIGNAL(triggered()), this , SLOT(doAction2()));
+
+    //List Widget Filtered
+    listWidgetFiltered = new QListWidget(centralWidget());
+    connect(listWidgetFiltered, SIGNAL(clicked(QModelIndex)), this, SLOT(itemClicked(QModelIndex)));
+    listWidgetFiltered->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
+    listWidgetFiltered->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    listWidgetFiltered->setStyleSheet(m_StyleQListWidget);
+
+    //Minimize Button
+    pushButtonMinimize = new QPushButton(centralWidget());
+    connect(pushButtonMinimize, SIGNAL(clicked()), this, SLOT(minimizeButtonClicked()));
+    pushButtonMinimize->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    pushButtonMinimize->setText("Toggle");
+
+    //Exit Button
+    pushButtonExit     = new QPushButton(centralWidget());
+    connect(pushButtonExit, SIGNAL(clicked()), this, SLOT(exitButtonClicked()));
+    pushButtonExit->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    pushButtonExit->setText("Exit");
+
+    //LineEdit
+    lineEditFilter  = new QLineEdit(centralWidget());
+    connect(lineEditFilter, SIGNAL(textChanged(QString)),this, SLOT(lineEditTextChanged(QString)));
+    lineEditFilter->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    //Clear Button
+    pushButtonClear = new QPushButton(centralWidget());
+    connect(pushButtonClear, SIGNAL(clicked()), this, SLOT(clearButtonClicked()));
+    pushButtonClear->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    pushButtonClear->setText("<");
+    //Reset Button
+    pushButtonReset = new QPushButton(centralWidget());
+    connect(pushButtonReset, SIGNAL(clicked()), this, SLOT(resetButtonClicked()));
+    pushButtonReset->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    pushButtonReset->setText("Reset");
+
+    //Letters Grid
+    lettersGridLayoutWidget = new QWidget(centralWidget());
+    lettersGridLayout = new QGridLayout();
+    lettersGridLayout->setSpacing(0);
+    lettersGridLayout->setMargin(0);
+    lettersGridLayoutWidget->setLayout(lettersGridLayout);
 }
 
 void horizontalcall::createPortraitUI()
 {
-    qDebug("Creating Portrait UI");
+    qDebug("Main Thread : Creating Portrait UI");
     //Create Main Layout
     mainLayoutPortrait = new QVBoxLayout();
     mainLayoutPortrait->setSpacing(0);
@@ -142,12 +199,16 @@ void horizontalcall::createPortraitUI()
     //Take care of top middle and bottom
     //Top
     topWidget = new QWidget(centralWidget());
-    topWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    topWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
+    topWidget->setFixedHeight(70);
     mainLayoutPortrait->addWidget(topWidget);
     topLayout = new QHBoxLayout();
     topLayout->setSpacing(0);
     topLayout->setMargin(0);
     topWidget->setLayout(topLayout);
+
+    //List Widget filtered in top right
+    mainLayoutPortrait->addWidget(listWidgetFiltered);
     //Middle
     middleWidget = new QWidget(centralWidget());
     middleWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -157,71 +218,27 @@ void horizontalcall::createPortraitUI()
     middleLayout->setSpacing(0);
     middleLayout->setMargin(0);
     middleWidget->setLayout(middleLayout);
-    //Bottom
-    lettersGridLayoutWidget = new QWidget(centralWidget());
+
+    //Grid
     lettersGridLayoutWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
     lettersGridLayoutWidget->setFixedHeight(400);
     mainLayoutPortrait->addWidget(lettersGridLayoutWidget);
-    lettersGridLayout = new QGridLayout();
-    lettersGridLayout->setSpacing(0);
-    lettersGridLayout->setMargin(0);
-    lettersGridLayoutWidget->setLayout(lettersGridLayout);
+    lettersGridLayoutWidget->setLayout(lettersGridLayout);lettersGridLayoutWidget->setLayout(lettersGridLayout);
 
-    //List Widget filtered in top right
-    listWidgetFiltered = new QListWidget(topWidget);
-    connect(listWidgetFiltered, SIGNAL(clicked(QModelIndex)), this, SLOT(itemClicked(QModelIndex)));
-    listWidgetFiltered->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    listWidgetFiltered->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    listWidgetFiltered->setStyleSheet(m_StyleQListWidget);
-    topLayout->addWidget(listWidgetFiltered);
 
-    //Take care of window controls in top left
-    windowControlsWidget = new QWidget(topWidget);
-    windowControlsWidget->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
-    windowControlsWidget->setFixedWidth(200);
-    topLayout->addWidget(windowControlsWidget);
-    windowControlsLayoutPortrait = new QVBoxLayout();
-    windowControlsLayoutPortrait->setSpacing(0);
-    windowControlsLayoutPortrait->setMargin(0);
-    windowControlsWidget->setLayout(windowControlsLayoutPortrait);
-    //Exit
-    pushButtonExit     = new QPushButton(topWidget);
-    pushButtonExit->setStyleSheet(m_StylePhoneNumbersShort);
-    connect(pushButtonExit, SIGNAL(clicked()), this, SLOT(exitButtonClicked()));
-    pushButtonExit->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    pushButtonExit->setText("Exit");
-    windowControlsLayoutPortrait->addWidget(pushButtonExit);
     //Minimize
-    pushButtonMinimize = new QPushButton(topWidget);
-    pushButtonMinimize->setStyleSheet(m_StylePhoneNumbersShort);
-    connect(pushButtonMinimize, SIGNAL(clicked()), this, SLOT(minimizeButtonClicked()));
-    pushButtonMinimize->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    pushButtonMinimize->setText("Toggle");
-    windowControlsLayoutPortrait->addWidget(pushButtonMinimize);
-    //Label
-    labelSelector = new QLabel(topWidget);
-    labelSelector->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    labelSelector->setAlignment(Qt::AlignCenter);
-    windowControlsLayoutPortrait->addWidget(labelSelector);
+    topLayout->addWidget(pushButtonMinimize);
 
-    //Take care of filter controls middle widget
-    //LineEdit
-    lineEditFilter  = new QLineEdit(middleWidget);
-    connect(lineEditFilter, SIGNAL(textChanged(QString)),this, SLOT(lineEditTextChanged(QString)));
-    lineEditFilter->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    //Clear Button
-    pushButtonClear = new QPushButton(middleWidget);
-    connect(pushButtonClear, SIGNAL(clicked()), this, SLOT(clearButtonClicked()));
-    pushButtonClear->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    pushButtonClear->setText("<");
-    //Reset Button
-    pushButtonReset = new QPushButton(middleWidget);
-    connect(pushButtonReset, SIGNAL(clicked()), this, SLOT(resetButtonClicked()));
-    pushButtonReset->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    pushButtonReset->setText("Reset");
-    //Add to layout
+    //Exit
+    topLayout->addWidget(pushButtonExit);
+
+    //Line Edit Filter
     middleLayout->addWidget(lineEditFilter);
+
+    //Clear Button
     middleLayout->addWidget(pushButtonClear);
+
+    //Reset Button
     middleLayout->addWidget(pushButtonReset);
 
     ui->centralWidget->show();
@@ -230,7 +247,7 @@ void horizontalcall::createPortraitUI()
 
 void horizontalcall::createLandscapeUI()
 {
-    qDebug("Creating Landscape UI");
+    qDebug("Main Thread : Creating Landscape UI");
     //Create Main Layout
     mainLayout = new QHBoxLayout();
     mainLayout->setSpacing(0);
@@ -244,7 +261,6 @@ void horizontalcall::createLandscapeUI()
     leftLayout = new QVBoxLayout();
     leftLayout->setSpacing(0);
     leftLayout->setMargin(0);
-    //leftLayout->setSizeConstraint(QLayout::SetMaximumSize);
     leftWidget->setLayout(leftLayout);
     rightWidget = new QWidget(centralWidget());
     rightWidget->setSizePolicy(QSizePolicy::Fixed, QSizePolicy::Expanding);
@@ -264,28 +280,21 @@ void horizontalcall::createLandscapeUI()
     filterControlsLayout->setSpacing(0);
     filterControlsLayout->setMargin(0);
     filterControlsWidget->setLayout(filterControlsLayout);
-    lineEditFilter  = new QLineEdit(leftWidget);
-    connect(lineEditFilter, SIGNAL(textChanged(QString)),this, SLOT(lineEditTextChanged(QString)));
-    lineEditFilter->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    pushButtonClear = new QPushButton(leftWidget);
-    connect(pushButtonClear, SIGNAL(clicked()), this, SLOT(clearButtonClicked()));
-    pushButtonClear->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    pushButtonClear->setText("<");
-    pushButtonReset = new QPushButton(leftWidget);
-    connect(pushButtonReset, SIGNAL(clicked()), this, SLOT(resetButtonClicked()));
-    pushButtonReset->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    pushButtonReset->setText("Reset");
+
+    //Line Edit Filter
     filterControlsLayout->addWidget(lineEditFilter);
+
+    //Clear Button
     filterControlsLayout->addWidget(pushButtonClear);
+
+    //Reset Button
     filterControlsLayout->addWidget(pushButtonReset);
 
     //Take care of grid layout for letters / details
-    lettersGridLayoutWidget = new QWidget(leftWidget);
     lettersGridLayoutWidget->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
+    lettersGridLayoutWidget->setMaximumHeight(1000);
+    lettersGridLayoutWidget->setMinimumHeight(0);
     leftLayout->addWidget(lettersGridLayoutWidget);
-    lettersGridLayout = new QGridLayout();
-    lettersGridLayout->setSpacing(0);
-    lettersGridLayout->setMargin(0);
     lettersGridLayoutWidget->setLayout(lettersGridLayout);
 
     //Take care of window controls
@@ -298,31 +307,14 @@ void horizontalcall::createLandscapeUI()
     windowControlsLayout->setMargin(0);
     windowControlsWidget->setLayout(windowControlsLayout);
     rightWidget->setLayout(windowControlsLayout);
-    pushButtonMinimize = new QPushButton(rightWidget);
-    connect(pushButtonMinimize, SIGNAL(clicked()), this, SLOT(minimizeButtonClicked()));
-    pushButtonMinimize->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    pushButtonMinimize->setText("Toggle");
-    pushButtonExit     = new QPushButton(rightWidget);
-    connect(pushButtonExit, SIGNAL(clicked()), this, SLOT(exitButtonClicked()));
-    pushButtonExit->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    pushButtonExit->setText("Exit");
+
+    //Minimize Button
     windowControlsLayout->addWidget(pushButtonMinimize);
+
+    //Exit Button
     windowControlsLayout->addWidget(pushButtonExit);
 
-    //Label
-    labelSelector = new QLabel(rightWidget);
-    labelSelector->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
-    labelSelector->setFixedHeight(50);
-    labelSelector->setAlignment(Qt::AlignCenter);
-    labelSelector->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    rightLayout->addWidget(labelSelector);
-
     //List Widget filtered
-    listWidgetFiltered = new QListWidget(rightWidget);
-    connect(listWidgetFiltered, SIGNAL(clicked(QModelIndex)), this, SLOT(itemClicked(QModelIndex)));
-    listWidgetFiltered->setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
-    listWidgetFiltered->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
-    listWidgetFiltered->setStyleSheet(m_StyleQListWidget);
     rightLayout->addWidget(listWidgetFiltered);
 
     ui->centralWidget->show();
@@ -331,92 +323,91 @@ void horizontalcall::createLandscapeUI()
 
 void horizontalcall::resizeEvent(QResizeEvent *e)
 {
-    qDebug("Resize Event");
-    if (m_FetchPending) {
-        qDebug("Still fetching contacts, Ignoring rotation.");
-        return;
-    }
+    QMainWindow::resizeEvent(e);
+
+    QSettings settings;
+    qDebug("Main Thread : Resize Event");
+    //    if (m_FetchPending) {
+    //        qDebug("Main Thread : Still fetching contacts, Ignoring rotation.");
+    //        return;
+    //    }
+
+    qDebug() << "width=" << width() << "height=" << height();
+
     if (width() > height())
     {
-        qDebug("Landscape Mode Recognized");
+        qDebug("Main Thread : Landscape Mode Recognized");
         if (m_Landscape)
         {
-            qDebug("Already In Landscape Mode");
+            qDebug("Main Thread : Already In Landscape Mode");
             return;
         } else {
             m_Landscape = true;
             destroyPortraitUI();
             createLandscapeUI();
+            settings.setValue("ManualRotationLandscape", true);
         }
     } else {
-        qDebug("Portratin Mode Recognized");
+        qDebug("Main Thread : Portratin Mode Recognized");
         if (!m_Landscape) {
-            qDebug("Already In Portrait Mode");
+            qDebug("Main Thread : Already In Portrait Mode");
             return;
         } else {
             m_Landscape = false;
             destroyLandscapeUI();
             createPortraitUI();
+            settings.setValue("ManualRotationLandscape", false);
         }
     }
-    fillListWidget();
 
     if (m_DisplayingContact) {
         listWidgetFiltered->setCurrentRow(m_CurrentRow);
         lineEditFilter->setText(m_CurrentFilter);
         showContactDetails(m_CurrentRow);
-        m_LabelSelector = QString::number(m_CurrentRow) + " / " + QString::number(m_Contacts.length());
-        labelSelector->setText(m_LabelSelector);
 
     } else {
         lineEditFilter->setText(m_CurrentFilter);
-        qDebug("Calling lineEdit Text Changed After UI Change");
+        qDebug("Main Thread : Calling lineEdit Text Changed After UI Change");
         lineEditTextChanged(m_CurrentFilter);
     }
-    labelSelector->setText(m_LabelSelector);
+
+    /*if (isFullScreen())
+    {
+        if (m_Landscape) {
+            this->resize(800,480);
+        } else {
+            this->resize(480,800);
+        }
+    } else {
+        if (m_Landscape) {
+            this->resize(800,424);
+        } else {
+            this->resize(480,744);
+        }
+    }*/
 }
 
-void horizontalcall::fillListWidget()
+void horizontalcall::AddContact(QContact temp)
 {
-    for (int i = 0; i < m_Contacts.size(); i++)
-    {
-        QContact temp = m_Contacts.at(i);
-        QContactDisplayLabel displayLabel = temp.detail(QContactDisplayLabel::DefinitionName);
-
-        if (!isAllEnglish(displayLabel.label()))
-        {
-            m_Contacts.removeAt(i);
-            i--;
-            continue;
-
-        }
-
-        if (!doesPhoneNumberExist(&temp))
-        {
-            m_Contacts.removeAt(i);
-            i--;
-            continue;
-        }
-
-        listWidgetFiltered->addItem(displayLabel.label());
-        QStringList tempQStringList = displayLabel.label().split(" ", QString::SkipEmptyParts);
-        tempQStringList.append(displayLabel.label());
-        m_NameStrings.append(tempQStringList);
-        //qDebug() << "NameStrings Size : " << m_NameStrings.size();
-    }
+    qDebug() << "Main Thread : Got contact to update.";
+    QContactDisplayLabel displayLabel = temp.detail(QContactDisplayLabel::DefinitionName);
+    listWidgetFiltered->addItem(displayLabel.label());
+    QStringList tempQStringList = displayLabel.label().split(" ", QString::SkipEmptyParts);
+    tempQStringList.append(displayLabel.label());
+    m_NameStrings.append(tempQStringList);
 }
 
 void horizontalcall::init()
 {
-    existingLetterButtons->clear();
-    existingLetters->clear();
-    m_NameStrings.clear();
+    //existingLetterButtons->clear();
+    //existingLetters->clear();
+    //m_NameStrings.clear();
     row = col = currentLetter = 0;
 }
 
 void horizontalcall::destroyLandscapeUI()
 {
-    qDebug("Destroying Landscape UI");
+    qDebug("Main Thread : Destroying Landscape UI");
     leftWidget->close();
     rightWidget->close();
     delete mainLayout;
@@ -424,26 +415,24 @@ void horizontalcall::destroyLandscapeUI()
 
 void horizontalcall::destroyPortraitUI()
 {
-    qDebug("Destroying Portrait UI");
+    qDebug("Main Thread : Destroying Portrait UI");
     topWidget->close();
     middleWidget->close();
-    lettersGridLayoutWidget->close();
+    //lettersGridLayoutWidget->close();
     delete mainLayoutPortrait;
 }
 
 void horizontalcall::minimizeButtonClicked()
 {
-    if (m_Maximized)
+    if (isFullScreen())
     {
         this->showNormal();
-        m_Maximized = false;
-        //this->setGeometry(0,0,800,390);
+        AppSettingsManager::setShouldLaunchFullscreen(false);
     }
     else
     {
         this->showFullScreen();
-        m_Maximized = true;
-        //this->setGeometry(0,0,800,480);
+        AppSettingsManager::setShouldLaunchFullscreen(true);
     }
 }
 
@@ -451,59 +440,76 @@ void horizontalcall::createStyle()
 {
     m_StyleLetters =
             "QPushButton {\
-                min-height: 1.5em;\
-                font: 1em;\
-                margin: 0 1px 0 1px;\
-                color: white;\
-                background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2198c0, stop: 1 #0d5ca6);\
-                border-style: outset;\
-                border-radius: 3px;\
-                border-width: 1px;\
-                border-color: #0c457e;\
-                font-size: 40px;\
-            }\
-            QPushButton:pressed {\
-                background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #0d5ca6, stop: 1 #2198c0);\
-    }";
+                          min-height: 1.5em;\
+                          font: 1em;\
+                              margin: 0 1px 0 1px;\
+                                  color: white;\
+                                      background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2198c0, stop: 1 #0d5ca6);\
+                                      border-style: outset;\
+                                      border-radius: 3px;\
+                                      border-width: 1px;\
+                                      border-color: #0c457e;\
+                                      font-size: 40px;\
+                                  }\
+QPushButton:pressed {\
+                     background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #0d5ca6, stop: 1 #2198c0);\
+                 }";
     getExternalStyleSheet(&m_StyleLetters, "/opt/horizontal-call/styleSheets/styleSheetLetters.qss");
+    m_StyleLettersSmaller =
+            "QPushButton {\
+                          min-height: 1.5em;\
+                          font: 1em;\
+                              margin: 0 1px 0 1px;\
+                                  color: white;\
+                                      background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2198c0, stop: 1 #0d5ca6);\
+                                      border-style: outset;\
+                                      border-radius: 3px;\
+                                      border-width: 1px;\
+                                      border-color: #0c457e;\
+                                      font-size: 32px;\
+                                  }\
+QPushButton:pressed {\
+                     background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #0d5ca6, stop: 1 #2198c0);\
+                 }";
+    getExternalStyleSheet(&m_StyleLettersSmaller, "/opt/horizontal-call/styleSheets/styleSheetLettersSmaller.qss");
     m_StylePhoneNumbers =
             "QPushButton {\
-                min-height: 1.5em;\
-                font: 1em;\
-                margin: 0 1px 0 1px;\
-                color: white;\
-                background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2198c0, stop: 1 #0d5ca6);\
-                border-style: outset;\
-                border-radius: 3px;\
-                border-width: 1px;\
-                border-color: #0c457e;\
-                font-size: 80px;\
-            }\
-            QPushButton:pressed {\
-                background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #0d5ca6, stop: 1 #2198c0);\
-    }";
+                          min-height: 1.5em;\
+                          font: 1em;\
+                              margin: 0 1px 0 1px;\
+                                  color: white;\
+                                      background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2198c0, stop: 1 #0d5ca6);\
+                                      border-style: outset;\
+                                      border-radius: 3px;\
+                                      border-width: 1px;\
+                                      border-color: #0c457e;\
+                                      font-size: 80px;\
+                                  }\
+QPushButton:pressed {\
+                     background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #0d5ca6, stop: 1 #2198c0);\
+                 }";
     getExternalStyleSheet(&m_StylePhoneNumbers, "/opt/horizontal-call/styleSheets/styleSheetPhoneNumbers.qss");
     m_StylePhoneNumbersShort =
             "QPushButton {\
-                min-height: 1.5em;\
-                font: 1em;\
-                margin: 0 1px 0 1px;\
-                color: white;\
-                background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2198c0, stop: 1 #0d5ca6);\
-                border-style: outset;\
-                border-radius: 3px;\
-                border-width: 1px;\
-                border-color: #0c457e;\
-                font-size: 60px;\
-            }\
-            QPushButton:pressed {\
-                background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #0d5ca6, stop: 1 #2198c0);\
-    }";
+                          min-height: 1.5em;\
+                          font: 1em;\
+                              margin: 0 1px 0 1px;\
+                                  color: white;\
+                                      background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #2198c0, stop: 1 #0d5ca6);\
+                                      border-style: outset;\
+                                      border-radius: 3px;\
+                                      border-width: 1px;\
+                                      border-color: #0c457e;\
+                                      font-size: 60px;\
+                                  }\
+QPushButton:pressed {\
+                     background-color: qlineargradient(x1: 0, y1: 0, x2: 0, y2: 1, stop: 0 #0d5ca6, stop: 1 #2198c0);\
+                 }";
     getExternalStyleSheet(&m_StylePhoneNumbersShort, "/opt/horizontal-call/styleSheets/styleSheetPhoneNumbersShort.qss");
     m_StyleQListWidget =
             "QListWidget {\
-                font-size: 30px;\
-    }";
+                          font-size: 30px;\
+                      }";
     getExternalStyleSheet(&m_StyleQListWidget, "/opt/horizontal-call/styleSheets/styleSheetQListWidget.qss");
 }
 
@@ -528,8 +534,6 @@ void horizontalcall::clearButtonClicked()
 
 void horizontalcall::lineEditTextChanged(QString text)
 {
-
-    //this->setUpdatesEnabled(false);
     m_CurrentFilter = text;
     m_DisplayingContact = false;
     pushButtonClear->setText("<");
@@ -573,7 +577,6 @@ void horizontalcall::lineEditTextChanged(QString text)
         m_DisplayingContact = true;
         m_CurrentRow = m_LastVisibleItemRow;
         showContactDetails(m_LastVisibleItemRow);
-        labelSelector->setText(QString::number(m_LastVisibleItemRow) + " / " + QString::number(m_Contacts.length()));
         listWidgetFiltered->setCurrentRow(m_LastVisibleItemRow);
     } else {
         scanContacts();
@@ -584,7 +587,7 @@ void horizontalcall::lineEditTextChanged(QString text)
 
 void horizontalcall::createLetters()
 {
-    qDebug() << "Size : " << existingLetters->size();
+    qDebug() << "Main Thread : Size : " << existingLetters->size();
     for (int i = 0; i < existingLetters->size(); i++)
     {
         CreateLetter(existingLetters->at(i));
@@ -602,12 +605,6 @@ void horizontalcall::deleteLetters()
     row = col = 0;
 }
 
-void horizontalcall::populateList()
-{
-    lineEditFilter->insert("Populating List...");
-    getContactsFromMemory();
-}
-
 void horizontalcall::exitButtonClicked()
 {
     exit(0);
@@ -615,7 +612,7 @@ void horizontalcall::exitButtonClicked()
 
 void horizontalcall::scanContacts()
 {
-    //qDebug() << "Scanning Contacts - Namestrings size is : " << m_NameStrings.size();
+    //qDebug() << "Main Thread : Scanning Contacts - Namestrings size is : " << m_NameStrings.size();
     existingLetters->clear();
     for (int i = 0; i < (m_NameStrings.count()); i++)
     {
@@ -633,7 +630,7 @@ void horizontalcall::scanContacts()
                 temp.at(0) != '\0' &&
                 ((QString)m_NameStrings.at(i).at(j)).toUpper().startsWith(lineEditFilter->text().toUpper()))
             {
-                //qDebug() << "Adding : '" << temp << "' to existing letters";
+                //qDebug() << "Main Thread : Adding : '" << temp << "' to existing letters";
                 existingLetters->append(temp.toUpper());
             }
         }
@@ -641,50 +638,28 @@ void horizontalcall::scanContacts()
     qSort(*existingLetters);
 }
 
-/*
-bool caseInsensitiveLessThan(const QString &s1, const QString &s2)
-{
-    return s1.toLower() < s2.toLower();
-}
-*/
-
 void horizontalcall::makeDbusGSMCall(QString number)
 {
     QDBusMessage msg = QDBusMessage::createMethodCall(
-        "com.nokia.csd.Call", // --dest
-        "/com/nokia/csd/call", // destination object path
-        "com.nokia.csd.Call", // message name (w/o method)
-        "CreateWith" // method
-    );
+            "com.nokia.csd.Call", // --dest
+            "/com/nokia/csd/call", // destination object path
+            "com.nokia.csd.Call", // message name (w/o method)
+            "CreateWith" // method
+            );
     msg << number;
     msg << 0;
     msg = QDBusConnection::systemBus().call(msg);
 }
 
-void horizontalcall::populateListWidget()
+void horizontalcall::Copy_m_Contacts(QList<QtMobility::QContact> i_Contacts)
 {
-    getContactsFromMemory();
-}
-
-bool horizontalcall::doesPhoneNumberExist(QContact *i_Contact)
-{
-    bool foundPhoneNumber = false;
-    QList<QContactDetail> details = i_Contact->details();
-    for (int z=0;z < details.size(); z++)
-    {
-        QString temp = details.at(z).definitionName();
-        if (temp == "PhoneNumber") {
-            foundPhoneNumber = true;
-        }
-    }
-
-    return foundPhoneNumber;
+    m_Contacts = i_Contacts;
+    qDebug() << "Main Thread : Copied m_Contacts, size is : " << m_Contacts.size();
 }
 
 void horizontalcall::showContactDetails(int row)
 {
-    //this->setUpdatesEnabled(false);
-    qDebug() << "Printing contact in row : " << row;
+    qDebug() << "Main Thread : Printing contact in row : " << row;
     pushButtonClear->setText("Back");
     deleteLetters();
 
@@ -718,7 +693,7 @@ void horizontalcall::showContactDetails(int row)
 
 
     QContact a = m_Contacts.at(row);
-    qDebug(a.displayLabel().toAscii());
+    qDebug("Main Thread : " + a.displayLabel().toAscii());
 
     QList<QContactPhoneNumber> allDetails = a.details<QContactPhoneNumber>();
 
@@ -768,33 +743,17 @@ void horizontalcall::enableButtons()
 
 void horizontalcall::itemClicked(QModelIndex model)
 {
-    //qDebug("Row Clicked : " + QString::number(model.row()).toAscii());
+    //qDebug("Main Thread : Row Clicked : " + QString::number(model.row()).toAscii());
     showContactDetails(model.row());
-    labelSelector->setText(QString::number(model.row()) + " / " + QString::number(m_Contacts.length()));
     m_CurrentRow = model.row();
 }
 
-void horizontalcall::getContactsFromMemory()
-{
-    QContactManager *pManager = new QContactManager();
-    m_FetchRequest->setManager(pManager);
-    QContactSortOrder nameOrder;
-    nameOrder.setDetailDefinitionName(QContactName::DefinitionName, QContactName::FieldFirstName);
-    m_FetchRequest->setSorting(QList<QContactSortOrder>() << nameOrder);
-    connect(m_FetchRequest, SIGNAL(resultsAvailable()), this, SLOT(printContacts()));
-
-    // async
-    if (!m_FetchRequest->start()) {
-
-    }
-}
-
 bool horizontalcall::getExternalStyleSheet(QString *styleSheet, QString fileName)
 {
     QFile qss(fileName);
     if (!qss.exists())
     {
-        qDebug("Style sheet file not found.");
+        qDebug("Main Thread : Style sheet file not found.");
         return false;
     }
 
@@ -806,54 +765,23 @@ bool horizontalcall::getExternalStyleSheet(QString *styleSheet, QString fileName
     return true;
 }
 
-bool horizontalcall::isAllEnglish(QString label)
-{
-    bool retVal = true;
-    for (int i = 0; i < label.length(); i++)
-    {
-        if (!(label.at(i) >= 32 && label.at(i) <= 126))
-        {
-            retVal = false;
-        }
-    }
-
-    return retVal;
-}
-
 void horizontalcall::resetButtonClicked()
 {
     lineEditFilter->setText("");
     lineEditTextChanged("");
 }
 
-void horizontalcall::printContacts()
-{
-    qDebug("Printing contacts");
-    m_Contacts = m_FetchRequest->contacts();
-
-    fillListWidget();
-
-    lineEditFilter->clear();
-
-    lineEditTextChanged("");
-    labelSelector->setText(QString::number(m_Contacts.length()));
-    lineEditFilter->setReadOnly(false);
-    qDebug("Done Printing Contacts");
-    m_FetchPending = false;
-}
-
 void horizontalcall::CreateLetter(QString letter)
 {
     QPushButton *myButton;
-    if (m_Landscape) {
-        myButton = new QPushButton(leftWidget);
-    } else {
-        myButton = new QPushButton(lettersGridLayoutWidget);
-    }
+    myButton = new QPushButton(centralWidget());
 
     //http://wiki.forum.nokia.com/index.php/CS001501_-_Creating_a_gradient_background_for_a_QPushButton_with_style_sheet
 
-    myButton->setStyleSheet(m_StyleLetters);
+    if (existingLetters->size() > 30)
+        myButton->setStyleSheet(m_StyleLettersSmaller);
+    else
+        myButton->setStyleSheet(m_StyleLetters);
     myButton->setMaximumSize(10000,10000);
     myButton->setMinimumSize(0,0);
     myButton->sizePolicy().setVerticalPolicy(QSizePolicy::Expanding);
@@ -876,6 +804,7 @@ void horizontalcall::insertChar()
 {
     QPushButton *tempButton = qobject_cast<QPushButton *>(QObject::sender());
     lineEditFilter->insert(tempButton->text());
+    qDebug() << "Button Clicked";
     lineEditTextChanged(lineEditFilter->text());
 }
 
