@@ -1,30 +1,12 @@
 #ifndef HORIZONTALCALL_H
 #define HORIZONTALCALL_H
 
-#include <QMainWindow>
-#include <QModelIndex>
+#include <QtGui>
 #include <QContact>
-#include <QContactName>
-#include <QContactSortOrder>
-#include <QContactManager>
-#include <QContactFetchRequest>
-#include <QTimer>
-#include <QPushButton>
-#include <QToolButton>
-#include <QDBusMessage>
-#include <QDBusConnection>
 #include <QContactPhoneNumber>
-#include <QScrollArea>
-#include <QFile>
-#include <QtDebug>
-#include <QGridLayout>
-#include <QLineEdit>
-#include <QListWidget>
-#include <QLabel>
-#include <QMaemo5InformationBox>
-#include <QSettings>
-#include <QMenuBar>
-#include <QMenu>
+
+#include "contactsthreadworker.h"
+#include "qtmaemo5rotator.h"
 
 namespace Ui {
     class horizontalcall;
@@ -38,8 +20,6 @@ public slots:
     void clearButtonClicked();
     void exitButtonClicked();
     void itemClicked(QModelIndex model);
-    void printContacts();
-    void populateList();
     void insertChar();
     void lineEditTextChanged(QString text);
     void phoneNumberClicked();
@@ -48,6 +28,11 @@ public slots:
     void minimizeButtonClicked();
     void doAction1();
     void doAction2();
+    void AddContact(QtMobility::QContact temp);
+    void ContactUpdatesDone();
+    void Copy_m_Contacts(QList<QtMobility::QContact>);
+
+signals:
 
 public:
     explicit horizontalcall(QWidget *parent = 0);
@@ -59,6 +44,7 @@ protected:
 private:
     //Members
     Ui::horizontalcall *ui;
+    QtMaemo5Rotator *rotator;
     QList<QPushButton*> *existingLetterButtons;
     QList<QString> *existingLetters;
     QList<QtMobility::QContact> m_Contacts;
@@ -66,6 +52,7 @@ private:
     QString abc;
     QScrollArea *m_scrollArea;
     QString m_StyleLetters;
+    QString m_StyleLettersSmaller;
     QString m_StylePhoneNumbers;
     QString m_StylePhoneNumbersShort;
     QString m_StyleQListWidget;
@@ -80,7 +67,6 @@ private:
     int row, col;
     int m_VisibleItem;
     int m_LastVisibleItemRow;
-    bool m_Maximized;
     bool m_Landscape;
     bool m_FetchPending;
     bool m_DisplayingContact;
@@ -131,10 +117,6 @@ private:
 
     // Methods
     bool getExternalStyleSheet(QString *styleSheet, QString fileName);
-    bool isAllEnglish(QString label);
-    bool doesPhoneNumberExist(QtMobility::QContact *i_Contact);
-    void getContactsFromMemory();
-    void populateListWidget();
     void scanContacts();
     void deleteLetters();
     void createLetters();
